@@ -2,7 +2,7 @@
 sentry.models
 ~~~~~~~~~~~~~
 
-:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -16,11 +16,11 @@ import urlparse
 from datetime import datetime
 from indexer.models import BaseIndex
 
-
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import F
+from django.db.models.signals import post_syncdb, post_save
 from django.utils.datastructures import SortedDict
 from django.utils.encoding import smart_unicode
 from django.utils.translation import ugettext_lazy as _
@@ -170,6 +170,9 @@ class ProjectOption(Model):
         db_table = 'sentry_projectoptions'
         unique_together = (('project', 'key',),)
 
+    def __unicode__(self):
+        return u'project=%s, key=%s, value=%s' % (self.project_id, self.key, self.value)
+
 
 class ProjectMember(Model):
     """
@@ -186,6 +189,9 @@ class ProjectMember(Model):
     class Meta:
         unique_together = (('project', 'user'),)
 
+    def __unicode__(self):
+        return u'project=%s, user=%s, type=%s' % (self.project_id, self.user_id, self.get_type_display())
+
     def save(self, *args, **kwargs):
         if not self.public_key:
             self.public_key = ProjectMember.generate_api_key()
@@ -217,6 +223,9 @@ class ProjectDomain(Model):
     class Meta:
         unique_together = (('project', 'domain'),)
 
+    def __unicode__(self):
+        return u'project=%s, domain=%s' % (self.project_id, self.domain)
+
     @classmethod
     def test(cls, project, url, strict=False):
         """
@@ -250,6 +259,9 @@ class View(Model):
     verbose_name = models.CharField(max_length=200, null=True)
     verbose_name_plural = models.CharField(max_length=200, null=True)
 
+    def __unicode__(self):
+        return self.path
+
 
 class MessageBase(Model):
     """
@@ -563,5 +575,91 @@ class SearchToken(Model):
 class MessageIndex(BaseIndex):
     model = Event
 
-# Import modules to register various things
-from . import management
+
+## Register Signals
+
+def register_indexes():
+    """
+    Grabs all required indexes from filters and registers them.
+    """
+    from sentry.filters import Filter
+    logger = logging.getLogger('sentry.setup')
+    for cls in (f for f in Filter.objects.all() if f.column.startswith('data__')):
+        MessageIndex.objects.register_index(cls.column, index_to='group')
+        logger.debug('Registered index for for %r' % cls.column)
+register_indexes()
+
+
+def create_default_project(created_models, verbosity=2, **kwargs):
+    if Project in created_models:
+        try:
+            owner = User.objects.filter(is_staff=True, is_superuser=True).order_by('id')[0]
+        except IndexError:
+            owner = None
+
+        project, created = Project.objects.get_or_create(
+            id=1,
+            defaults=dict(
+                public=True,
+                name='Default',
+                owner=owner,
+            )
+        )
+        if not created:
+            return
+
+        if verbosity > 0:
+            print 'Created default Sentry project owned by %s' % owner
+
+        # Iterate all groups to update their relations
+        for model in (Group, Event, FilterValue, MessageFilterValue,
+                      MessageCountByMinute):
+            if verbosity > 0:
+                print ('Backfilling project ids for %s.. ' % model),
+            model.objects.filter(project__isnull=True).update(
+                project=project,
+            )
+            if verbosity > 0:
+                print 'done!'
+
+
+def create_project_member_for_owner(instance, created, **kwargs):
+    if not created:
+        return
+
+    if not instance.owner:
+        return
+
+    instance.member_set.create(
+        user=instance.owner,
+        type=globals()[settings.DEFAULT_PROJECT_ACCESS]
+    )
+
+
+def update_document(instance, created, **kwargs):
+    if created:
+        return
+
+    SearchDocument.objects.filter(
+        project=instance.project,
+        group=instance,
+    ).update(status=instance.status)
+
+# Signal registration
+post_syncdb.connect(
+    create_default_project,
+    dispatch_uid="create_default_project",
+    weak=False,
+)
+post_save.connect(
+    create_project_member_for_owner,
+    sender=Project,
+    dispatch_uid="create_project_member_for_owner",
+    weak=False,
+)
+post_save.connect(
+    update_document,
+    sender=Group,
+    dispatch_uid="update_document",
+    weak=False,
+)
\ No newline at end of file
